﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Threading;

namespace MvvmDataBindingDemo.Mvvm
{
    /// <summary>
    /// Behaviors for the TextBox class.
    /// </summary>
    public static class TextBoxExt
    {
        public static readonly DependencyProperty SelectAllOnFocusProperty = DependencyProperty.RegisterAttached(
            "SelectAllOnFocus",
            typeof(bool),
            typeof(TextBoxExt),
            new FrameworkPropertyMetadata(OnSelectAllOnFocusChanged));

        public static bool GetSelectAllOnFocus(TextBox d)
        {
            return (bool)d.GetValue(SelectAllOnFocusProperty);
        }

        public static void SetSelectAllOnFocus(TextBox d, bool value)
        {
            d.SetValue(SelectAllOnFocusProperty, value);
        }

        private static void OnSelectAllOnFocusChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var textBox = d as TextBox;
            if (textBox == null)
                throw new NotSupportedException("SelectAllOnFocus is applicable only to TextBox.");

            if ((bool)e.NewValue)
                textBox.GotFocus += OnGotFocus;
            else
                textBox.GotFocus -= OnGotFocus;
        }

        static void OnGotFocus(object sender, RoutedEventArgs e)
        {
            var textBox = (TextBox)sender;
            textBox.Dispatcher.BeginInvoke(DispatcherPriority.Input, new Action(textBox.SelectAll));
        } 
    }
}
